import {Component, ElementRef, ViewChild} from '@angular/core';
import {IonicPage, NavController, NavParams, Slide, Slides} from 'ionic-angular';
import {SearchNewPage} from "../../home-pages/search-new/search-new";
import {TabsService} from "../tabs.service";
import {StuffDetailPage} from "../../home-pages/stuff-detail/stuff-detail";
import {PublishPage} from "../../discover-pages/publish/publish";
import {EmitService} from "../../../provide/emit.service";
import {NoticePage} from "../notice/notice";
import {AppGlobal} from "../../../service/http.service";
import {CommonService} from "../../../provide/common.service";


@IonicPage()
@Component({
    selector: 'page-discover',
    templateUrl: 'discover.html',
})
export class DiscoverPage {
    @ViewChild(Slides) slides:Slides;
    @ViewChild('tips') tips: ElementRef;
    @ViewChild('tabsParent') tabsParent: ElementRef;
    @ViewChild('tabsChildren') tabsChildren: ElementRef;
    @ViewChild('tabSpan') tabSpan: ElementRef;
    @ViewChild('newsContent') newsContent: ElementRef;

    //所属板块类型:
    //1党章党规,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,8党务参考
    //9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶
    tabsList = [
        {
            "name": "机关党委", "type": 5, "indexParent": 0, "children": [
                {
                    "name": "最新",
                    "type": 5,
                    "indexChildren": '01'
                },
                {
                    "name": "通知公告",
                    "type": 5,
                    "indexChildren": '02'
                },
                {
                    "name": "党建动态",
                    "type": 6,
                    "indexChildren": '03'
                },
                {
                    "name": "工作提示",
                    "type": 7,
                    "indexChildren": '04'
                },
                {
                    "name": "党务参考",
                    "type": 8,
                    "indexChildren": '05'
                }
            ]
        },
        {
            "name": "支部风采", "type": 13, "indexParent": 1, "children": [
                {
                    "name": "推荐",
                    "type": 13,
                    "indexChildren": '11'
                },
                {
                    "name": "支部活动",
                    "type": 13,
                    "indexChildren": '12'
                },
                {
                    "name": "党建联建",
                    "type": 14,
                    "indexChildren": '13'
                },
                {
                    "name": "结对帮扶",
                    "type": 15,
                    "indexChildren": '14'
                }
            ]
        },
        {
            "name": "党风廉政", "type": 9, "indexParent": 2, "children": [
                {
                    "name": "最新",
                    "type": 9,
                    "indexChildren": '21'
                },
                {
                    "name": "廉政格言",
                    "type": 9,
                    "indexChildren": '22'
                },
                {
                    "name": "纪检提示",
                    "type": 10,
                    "indexChildren": '23'
                },
                {
                    "name": "风险排查",
                    "type": 11,
                    "indexChildren": '24'
                },
                {
                    "name": "警示教育",
                    "type": 12,
                    "indexChildren": '25'
                }
            ]
        },
        {
            "name": "互动交流", "type": -1, "indexParent": 3, "children": [
                {
                    "name": "最新",
                    "type": -1,
                    "indexChildren": '31'
                },
                {
                    "name": "学思践悟",
                    "type": -1,
                    "indexChildren": '32'
                },
                {
                    "name": "话题讨论",
                    "type": -1,
                    "indexChildren": '33'
                },
                {
                    "name": "你问我答",
                    "type": -1,
                    "indexChildren": '34'
                }]
        },
        // {"name": "知识拓展", "type": -1, "indexParent": 4, "children": []}
    ];
    childrenList = [];
    plateType;   //分类

    indexParent = 1;
    indexChildren = 0;
    newList;   //新闻列表

    noReadNum;
    picture: string = AppGlobal.domain + '/wisdomgroup';

    slideList = [];

    constructor(public navCtrl: NavController, public navParams: NavParams,
                public commonSer:CommonService,
                public tabsSer: TabsService, public emitSer: EmitService) {
        // 接收发射过来的数据
        this.emitSer.eventEmit.subscribe((value: any) => {
            if (!isNaN(value)) {
                this.noReadNum = value;
            }
        });
    }

    ionViewDidEnter() {
        this.slideList.length = 5;
        this.changeParent(this.tabsList[1]);
    }

    //父级选择
    changeParent(item) {
        this.newsContent.nativeElement.scrollLeft = 0;   //二级菜单滑动重置
        const index = item.indexParent;
        this.indexParent = index;
        this.plateType = item.type;
        this.childrenList = item.children;
        if(this.childrenList.length > 0) this.indexChildren = this.childrenList[0].indexChildren;
        let itemWidth = window.screen.width / 4;
        let spanWidth = this.tabSpan.nativeElement.offsetWidth;   //文字宽度
        this.tips.nativeElement.style.width = this.tabSpan.nativeElement.offsetWidth + 'px';
        // 自身div的一半 - 滑块的一半
        this.tips.nativeElement.style.left = itemWidth * (index) + (itemWidth - spanWidth) / 2 + 'px';
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': this.plateType,
                'resourceType': 1
            }
        };
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                });
                this.slides.slideTo(index,500);
                this.slideList[index] = this.newList;
            }
        )
    }

    //子级选择
    changeChildren(item) {
        this.indexChildren = item.indexChildren;
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': item.type,
                'resourceType': 1
            }
        };
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
            }
        )
    }


    //前往搜索页面
    goToSearch() {
        this.navCtrl.push(SearchNewPage);
    }

    //查看详情
    goToDetail(item) {
        this.navCtrl.push(StuffDetailPage, {
            id: item.id
        });
    }

    //前往发布页面
    goToPublish() {
        this.navCtrl.push(PublishPage);
    }

    //消息提醒页面
    goToNotice() {
        this.navCtrl.push(NoticePage);
    }

    doRefresh(e){
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': this.plateType,
                'resourceType': 1
            }
        };
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
                this.commonSer.toastTime('刷新成功!',800)
                e.complete();
            }
        )
    }

    doInfinite(e){
        e.complete();
    }

    slideChange(e){
       const index = this.slides.getActiveIndex();
       console.log(this.tabsList[index]);
       this.changeParent(this.tabsList[index])
    }
}
