import {Component, ElementRef, ViewChild, NgZone, Renderer2} from '@angular/core';
import {NavController, IonicPage, Slides, Content} from 'ionic-angular';
import {Http, Response} from '@angular/http';
import {AppService, AppGlobal} from '../../../service/http.service';
import {Storage} from '@ionic/storage';
import {NoticePage} from "../notice/notice";
import {Badge} from '@ionic-native/badge';
import {TabsService} from "../tabs.service";
import {TextToSpeech} from "@ionic-native/text-to-speech";
import {CommonService} from "../../../provide/common.service";
import {SearchNewPage} from "../../home-pages/search-new/search-new";
import {StuffDetailPage} from "../../home-pages/stuff-detail/stuff-detail";
import {EmitService} from "../../../provide/emit.service";
import {DatePipe} from "@angular/common";
import {SlideListComponent} from "../../../components/slide-list/slide-list";

@IonicPage()
@Component({
    selector: 'page-home',
    templateUrl: 'home.html'
})

export class HomePage {
    @ViewChild(Slides) slides: Slides;
    @ViewChild(Content) content: Content;
    @ViewChild('tips') tips: ElementRef;
    @ViewChild('tips1') tips1: ElementRef;
    @ViewChild('verticaLamp') verticaLamp: ElementRef;
    @ViewChild('tabSpan') tabSpan: ElementRef;
    @ViewChild('tabSpan1') tabSpan1: ElementRef;
    @ViewChild('topHeight') topHeight: ElementRef;
    @ViewChild('headerTag') headerTag: ElementRef;
    @ViewChild('homeMiddleTips') homeMiddleTips: ElementRef;

    picture: string = AppGlobal.domain + '/wisdomgroup';
    //所属板块类型:
    //1党章党规,2系列讲话,3中央精神,4本市部署,5通知公告,6党建动态,7工作提示,8党务参考
    //9廉政格言,10纪检提示,11风险排查,12警示教育,13支部活动,14党建联建,15结对帮扶
    tabsList = [
        {name: "系列讲话", type: 2, index: 0},
        {name: "党章党规", type: 1, index: 1},
        {name: "中央精神", type: 3, index: 2},
        {name: "本市部署", type: 4, index: 3}
    ];
    index = 0;
    isSign = false;   //签到弹窗
    isBir = false;  //政治生日弹窗
    isScroll = false;   //tabs置顶

    newList = [];
    noReadNum;

    signObj = {
        'text': '',
        'isSign': ''
    };   //签到参数
    disabledClick = true;
    signText;   //签到倒计时
    partyObj;  //政治生日



    constructor(public navCtrl: NavController, public tts: TextToSpeech, public datePipe: DatePipe,
                public commonSer: CommonService, public emitSer: EmitService,
                public zone: NgZone,public slideList:SlideListComponent,
                public appService: AppService, public http: Http, public storage: Storage,
                public badge: Badge, public tabsSer: TabsService) {
        // 接收发射过来的数据
        this.emitSer.eventEmit.subscribe((value: any) => {
            if (!isNaN(value)) {
                this.noReadNum = value;
            }
        });
    }

    ionViewDidEnter(){
        this.tabsSer.signNow().subscribe(
            (res) => {
                this.signObj = res.data;
            }
        );
    }

    ionViewDidLoad() {
        // this.change(this.tabsList[0]);
        this.getInfo();
        this.scrollHeight();
    }


    scrollHeight(){
        const height = this.topHeight.nativeElement.offsetHeight + 80;
        this.content.ionScroll.subscribe(($event)=>{
            this.zone.run(()=>{
                // this.headerTag.nativeElement.
                if(this.content.scrollTop > height){
                    this.slideList.scroll('true');
                }else{
                    this.slideList.scroll('false');
                }
                this.content.resize();
            })
        })
    }




    //获取党员生日
    getInfo() {
        this.storage.get("userLoginInfo").then((value) => {
            let userid = value.userid;
            this.tabsSer.getInfo(userid).subscribe(
                (res) => {
                    this.partyObj = res.apiResult.data;
                    //获取是否展示过政治生日
                    const nowDay = this.datePipe.transform( new Date(),'yyyy-MM-dd' );
                    const partyBir = localStorage.getItem('partyBir');
                    if(nowDay == partyBir){
                        this.start();
                        this.isBir = false;
                    }else{
                        this.isBir = true;
                    }
                }
            );
        })
    }

    //关闭弹窗 开启跑马灯
    start() {
        const nowDay = this.datePipe.transform( new Date(),'yyyy-MM-dd' );
        localStorage.setItem('partyBir',nowDay);

        this.isBir = false;
        this.homeMiddleTips.nativeElement.style.height = "60px";
        this.homeMiddleTips.nativeElement.style.padding = ".5rem";
        let child_div = this.verticaLamp.nativeElement.children;
        const scrollWidth = this.verticaLamp.nativeElement.offsetWidth;
        const textWidth = child_div[0].offsetWidth;

        let i = scrollWidth;
        setInterval(()=>{
            i--;
            if(i < -textWidth){
                i = scrollWidth;
            }
            child_div[0].style.left = i + 'px';
        },20)
    }


    change(item) {
        const index = item.index;
        let itemWidth = window.screen.width / 4;
        let spanWidth = this.tabSpan.nativeElement.offsetWidth;   //文字宽度
        this.tips.nativeElement.style.width = this.tabSpan.nativeElement.offsetWidth + 'px';
        this.tips1.nativeElement.style.width = this.tabSpan.nativeElement.offsetWidth + 'px';
        // 自身div的一半 - 滑块的一半
        this.tips.nativeElement.style.left = itemWidth * (index) + (itemWidth - spanWidth) / 2 + 'px';
        this.tips1.nativeElement.style.left = itemWidth * (index) + (itemWidth - spanWidth) / 2 + 'px';
        this.index = index;
        const data = {
            pageSize: 1,
            pageCount: 100,
            obj: {
                'plateType': item.type,
                'resourceType': 1
            }
        }
        this.tabsSer.stuffPage(data).subscribe(
            (res) => {
                this.newList = res.data;
                this.newList.forEach(e => {
                    if (e.attachments.length > 0) {
                        e.imgUrl = e.attachments[0].path;
                    }
                })
            }
        )
    }

    //签到接口
    signUp() {
        this.tabsSer.sign().subscribe(
            (res) => {
                this.isSign = false;
                if (res.errcode == '1000') {
                    this.commonSer.toast('签到成功');
                    this.signObj.isSign = 'yes';
                } else {
                    this.commonSer.toast(res.errmsg);
                }
            }
        )
    }

    //签到倒计时
    signNow() {
        this.isSign = true;
        let totalTime = 5;
        this.signText = '(倒计时' + totalTime + 's)';
        let clock = window.setInterval(() => {
            totalTime--;
            this.signText = '(倒计时' + totalTime + 's)';
            if (totalTime < 0) {
                this.signText = '';
                window.clearInterval(clock);
                this.disabledClick = false;
            }
        }, 1000)
    }

    //查看文章详情
    goToDetail(item) {
        this.navCtrl.push(StuffDetailPage, {
            id: item.id
        })
    }

    //前往搜索页面
    goToSearch() {
        this.navCtrl.push(SearchNewPage);
    }

    //消息提醒页面
    goToNotice() {
        this.navCtrl.push(NoticePage);
    }

    doInfinite(e){
        e.complete();
    }

    doRefresh(e){
      e.complete();
    }

}
