import {Component} from '@angular/core';
import {App, NavController, AlertController, NavParams} from 'ionic-angular';
import {AppGlobal, AppService} from '../../../service/http.service';
import {PersonInfoPage} from '../../mine/person/personInfo/personInfo';
import {MyActivityListPage} from '../../mine/myActivityList/myActivityList';
import {MyReportPage} from '../../mine/myReport/myReport';
import {OperationListPage} from '../../mine/operation-list/operation-list';
import {VersionPage} from '../../version/version';
import {Response} from '@angular/http';
import {Storage} from '@ionic/storage';

import {AppVersion} from '@ionic-native/app-version';
import {AppUpdateService} from "../../../service/appUpdate.service";
import {MyDutyPage} from "../../mine/my-duty/my-duty";
import {MySurveyPage} from "../../home/mySurvey/my-survey/my-survey";
import {TabsService} from "../tabs.service";
import {EmitService} from "../../../provide/emit.service";
import {NoticePage} from "../notice/notice";


@Component({
    selector: 'page-mine',
    templateUrl: 'mine.html',
})
export class MinePage {

    user;
    orgName: '';
    gender: object;
    version: string = '';
    isLatest: boolean = true;
    picture: string = AppGlobal.picture;
    picUrl;

    mineInfo;
    noReadNum;
    constructor(public navCtrl: NavController,
                private appCtrl: App,
                private alertCtrl: AlertController,
                public navParams: NavParams,
                public tabSer:TabsService,
                public appService: AppService,
                public emitSer:EmitService,
                public storage: Storage,public app:App,
                private appUpdateService: AppUpdateService,
                private appVersion: AppVersion) {
        // 接收发射过来的数据
        this.emitSer.eventEmit.subscribe((value: any) => {
            if(!isNaN(value)){
                this.noReadNum = value;
            }
        });
    }

    ionViewWillEnter() {
        this.user = this.storage.get("user").then((value) => {
            this.user = value;
            this.picUrl = this.user.userDetail.user.picUrl;
            this.gender = this.user.userDetail.user.gender;
        });
        this.getversion();
        this.tabSer.getUserIntegral().subscribe(
            (res)=>{
                this.mineInfo = res.data;
            }
        )
    }


    getOrgName(id, callback?): any {
        this.appService.ObserverHttpPost("/wisdomgroup/app/getOrgName", {"userid": id})
            .toPromise()
            .then(res => {
                var data = res.json();
                callback(data == null ? "[]" : data);
            })
            .catch(error => {
            });
    }

    personInfo() {
        this.navCtrl.push("PersonInfoPage");
    }

    //我的活动
    myActivityList() {
        this.navCtrl.push("MyActivityListPage");
    }

    //我的报备
    myReport() {
        this.navCtrl.push("MyReportPage");
    }

    //操作记录
    myOperationList() {
        this.navCtrl.push("OperationListPage");
    }

    //我的问卷
    mySurvey() {
        this.navCtrl.push('MySurveyPage');
    }

    //后台退出
    logoutApp() {
        this.appService.ObserverHttpGet("/wisdomgroup/app/logout", null)
            .subscribe((res: Response) => {
                    let data = res.json();
                }, error => {
                }
            );
    }

    //获取最新版本信息
    getversion() {
        //检测是否需要更新
        this.appVersion.getVersionNumber().then((version: string) => {
            this.version = version;
            this.appUpdateService.compariVersion().subscribe(data => {
                if (data.code == 200) {
                    if (data.latestVersion != null && data.latestVersion != version) {
                        this.isLatest = false;
                    }
                }
            });
        }).catch(err => {
        });
    }

    goSet() {
        // this.app.getRootNav().push('VersionPage');
        this.navCtrl.push('VersionPage');
    }

    goDuty() {
        this.navCtrl.push("MyDutyPage");
    }

    //消息提醒页面
    goToNotice(){
        this.navCtrl.push(NoticePage);
    }
}
